@@ -25,16 +25,9 @@
 
 namespace mixt {
 
-MultinomialStatistic::MultinomialStatistic() :
-		rng_(seed(this)), uni_(0., 1.), g_(rng_), generator_(rng_, uni_) {
-}
-;
-
 int MultinomialStatistic::sampleInt(int low, int high) {
-	boost::random::uniform_int_distribution<> uni(low, high);
-	boost::variate_generator<boost::random::mt19937&,
-			boost::random::uniform_int_distribution<> > generator(rng_, uni);
-	int x = generator();
+	std::uniform_int_distribution<int> uni_(low, high);
+	int x = uni_(rng_);
 	return x;
 }
 
